ViControl = {};

function ViControl.initSpecialization()

    local schemaSavegame = Vehicle.xmlSchemaSavegame   
    schemaSavegame:register(XMLValueType.INT, "vehicles.vehicle(?).VehicleInspector.ViControl#groupTyp", "Current GroupType index for GroupManager")

end;

function ViControl.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Enterable, specializations) and SpecializationUtil.hasSpecialization(Motorized, specializations) and SpecializationUtil.hasSpecialization(Drivable, specializations);
end;

function ViControl.registerFunctions(vehicleType)
    SpecializationUtil.registerFunction(vehicleType, "setViControlKey",            	ViControl.setViControlKey)    
    --SpecializationUtil.registerFunction(vehicleType, "MPEvent",            				ViControl.MPEvent)
end

function ViControl.registerEventListeners(vehicleType)
	local functionNames = {
		"onLoad"
		,"onPostLoad"
		,"onDelete"
		,"saveToXMLFile"		
		,"onReadStream"
		,"onWriteStream"
		,"onUpdate"
		,"onUpdateTick"
		,"onDraw"
	};
	
	for i, v in ipairs(functionNames) do
		SpecializationUtil.registerEventListener(vehicleType, v, ViControl);
	end;
end;

function ViControl:onLoad(savegame)	
	if g_dedicatedServer == nil and not viGroupManager.groupTyp.xmlLoaded then viGroupManagerXml:loadProfile(false);end;
	self.setViControlKey = ViControl.setViControlKey;	
		
	self.viControl = {};		
	local groupTypNumber = -1;
	groupTypNumber = viGroupManager:getFreeTypNumber();
	self.viControl.groupTyp = groupTypNumber;
	self.viControl.group = {};
	if self.viControl.groupTyp ~= nil and self.viControl.groupTyp > 0 then
		viGroupManager.groupTyp.freeNumbers[self.viControl.groupTyp] = false;
		if viGroupManager.groups[0][groupTypNumber] ~= nil and viGroupManager.groups[0][groupTypNumber].node == -1 then viGroupManager:insertGroupVehicle(self, 0);self.viIsMarked = true;end; --marked group 0		
	end;	
end;

function ViControl:onPostLoad(savegame)	
	if savegame ~= nil then
		if g_dedicatedServer == nil and not viGroupManager.groupTyp.xmlLoaded then viGroupManagerXml:loadProfile(false);end;
		local groupTypeNumber = savegame.xmlFile:getValue(savegame.key..".VehicleInspector.ViControl#groupTyp")
		if groupTypeNumber ~= nil then
			if groupTypeNumber <= 0 then --change
				local groupTypNumberChange = viGroupManager:getFreeTypNumber();
				if groupTypNumberChange > 0 then groupTypeNumber = groupTypNumberChange;end;
			end;
			self.viControl.groupTyp = groupTypeNumber;
			viGroupManager.groupTyp.freeNumbers[self.viControl.groupTyp] = false;			
			if viGroupManager.groups[0][groupTypNumber] ~= nil and viGroupManager.groups[0][groupTypNumber].node == -1 then viGroupManager:insertGroupVehicle(self, 0);self.viIsMarked = true;end; --marked group 0
		end;
	end;	
end;

function ViControl:onDelete()
	if self.viControl ~= nil and self.viControl.groupTyp ~= nil and self.viControl.groupTyp > 0 then		
		viGroupManager:deleteGroupVehicle(self, nil, true);		
		viGroupManager.groupTyp.freeNumbers[self.viControl.groupTyp] = true;
		viGroupManager.groupTyp.maxReached = false;		
		self.viControl.groupTyp = -1;		
	end;
end;

function ViControl:saveToXMLFile(xmlFile, key)
	
	xmlFile:setValue(key.."#groupTyp", self.viControl.groupTyp);

end;

function ViControl:onReadStream(streamId, connection)
    if connection:getIsServer() then
        self.viControl.groupTyp = streamReadInt8(streamId);		
    end;
end;

function ViControl:onWriteStream(streamId, connection)
    if not connection:getIsServer() then
        streamWriteInt8(streamId, self.viControl.groupTyp);		
    end;
end;

function ViControl:onUpdate(dt)

end;

function ViControl:onUpdateTick(dt)

end;

function ViControl:onDraw()

	if self.isClient and self.spec_enterable.isEntered and self.viControl ~= nil and self.viControl.groupTyp ~= nil and VehicleInspector.global.groupLine.viewGroupTyp then
		local cruiseOverlay = g_currentMission.inGameMenu.hud.speedMeter.cruiseControlElement.overlay;
		local posX = cruiseOverlay.x + cruiseOverlay.width * 1.3;
		local posY = cruiseOverlay.y + cruiseOverlay.height * 0.8;
		local txtSize = g_currentMission.inGameMenu.hud.speedMeter.cruiseControlTextSize * 0.55;
		local color = {1,1,1,1};
		if viGroupManager:isVehicleGroup(self) then			
			--if self.viIsMarked ~= nil and self.viIsMarked then
			--	color = g_currentMission.hl.getColor(VehicleInspector.showColor.selected, true);
			--else
				color = g_currentMission.hl.getColor("ls22", true);
			--end;
			setTextColor(unpack(color));		
		end;
		
		setTextBold(true);
		setTextAlignment(RenderText.ALIGN_LEFT);
		renderText(posX, posY, txtSize, tostring(self.viControl.groupTyp).."/T");
		setTextColor(1,1,1,1);
		setTextAlignment(0);
		setTextBold(false);
		--VehicleInspector.global.testString[1] = tostring(self.viControl.groupTyp)
	end;	

end;

function ViControl:setViControlKey(key)

	


end;

